@@ -3,6 +3,15 @@ spautolm <- function(formula, data = list(), listw, weights,
     na.action, family="SAR", method="eigen", verbose=NULL, trs=NULL,
     interval=NULL, zero.policy=NULL, tol.solve=.Machine$double.eps, llprof=NULL,
     control=list()) {
+    .Deprecated("spatialreg::spautolm", msg="Function spautolm moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+      if (!missing(weights)) stop("run spatialreg::spautolm directly")
+      return(spatialreg::spautolm(formula=formula, data=data, listw=listw, na.action=na.action, family = family, method=method, verbose=verbose, trs=trs, interval=interval, zero.policy=zero.policy, tol.solve=tol.solve, llprof=llprof, control=control))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
     timings <- list()
     .ptime_start <- proc.time()
     con <- list(tol.opt=.Machine$double.eps^(2/3), 
@@ -189,7 +198,9 @@ spautolm <- function(formula, data = list(), listw, weights,
     class(res) <- "spautolm"
     res
 }
+#}
 
+#if (FALSE) {
 .opt.fit <- function(lambda, env, tol.solve=.Machine$double.eps) {
 # fitting function called from optimize()
     SSE <- .SPAR.fit(lambda=lambda, env=env, out=FALSE, tol.solve=tol.solve)
@@ -244,9 +255,17 @@ SMA <- function(IlW, weights) {
     IlW <- solve(IlW)
     t(IlW) %*% weights %*% IlW
 }
-
+#}
 
 print.spautolm <- function(x, ...) {
+    .Deprecated("spatialreg::print.spautolm", msg="Method print.spautolm moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+      return(spatialreg::print.spautolm(x=x, ...))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
         if (isTRUE(all.equal(x$lambda, x$interval[1])) ||
             isTRUE(all.equal(x$lambda, x$interval[2]))) 
             warning("lambda on interval bound - results should not be used")
@@ -258,29 +277,74 @@ print.spautolm <- function(x, ...) {
 	invisible(x)
     
 }
+#}
 
 residuals.spautolm <- function(object, ...) {
+    .Deprecated("spatialreg::residuals.spautolm", msg="Method residuals.spautolm moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+      return(spatialreg::residuals.spautolm(object=object, ...))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
 	if (is.null(object$na.action))
 		object$fit$residuals
 	else napredict(object$na.action, object$fit$residuals)
 }
+#}
 
 fitted.spautolm <- function(object, ...) {
+    .Deprecated("spatialreg::fitted.spautolm", msg="Method fitted.spautolm moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+      return(spatialreg::fitted.spautolm(object=object, ...))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
 	if (is.null(object$na.action))
 		object$fit$fitted.values
 	else napredict(object$na.action, object$fit$fitted.values)
 }
+#}
 
 deviance.spautolm <- function(object, ...) {
+    .Deprecated("spatialreg::deviance.spautolm", msg="Method deviance.spautolm moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+      return(spatialreg::deviance.spautolm(object=object, ...))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
 	object$SSE
 }
+#}
 
 coef.spautolm <- function(object, ...) {
+    .Deprecated("spatialreg::coef.spautolm", msg="Method coef.spautolm moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+      return(spatialreg::coef.spautolm(object=object, ...))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
 	c(object$fit$coefficients, object$lambda)
 }
+#}
 
 
 logLik.spautolm <- function(object, ...) {
+    .Deprecated("spatialreg::logLik.spautolm", msg="Method logLik.spautolm moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+      return(spatialreg::logLik.spautolm(object=object, ...))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
 	LL <- c(object$LL)
 	class(LL) <- "logLik"
 	N <- object$fit$N
@@ -289,9 +353,17 @@ logLik.spautolm <- function(object, ...) {
 	attr(LL, "df") <- object$parameters
 	LL
 }
+#}
 
-LR1.spautolm <- function(object)
-{
+LR1.spautolm <- function(object) {
+    .Deprecated("spatialreg::LR1.spautolm", msg="Method LR1.spautolm moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+      return(spatialreg::LR1.spautolm(object=object))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
 	if (!inherits(object, "spautolm")) stop("Not a spautolm object")
 	LLx <- logLik(object)
 	LLy <- object$LL0
@@ -309,9 +381,19 @@ LR1.spautolm <- function(object)
 	class(res) <- "htest"
 	res
 }
+#}
 
 summary.spautolm <- function(object, correlation = FALSE, adj.se=FALSE,
  Nagelkerke=FALSE, ...) {
+    .Deprecated("spatialreg::summary.spautolm", msg="Method summary.spautolm moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+      return(spatialreg::summary.spautolm(object=object, correlation = correlation, adj.se=adj.se,
+ Nagelkerke=Nagelkerke, ...))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
 	N <- object$fit$N
 	adj <- ifelse (adj.se, N/(N-length(object$fit$coefficients)), 1) 
 	object$fit$s2 <- object$fit$s2*adj
@@ -340,10 +422,20 @@ summary.spautolm <- function(object, correlation = FALSE, adj.se=FALSE,
 	rownames(object$Coef) <- names(object$fit$coefficients)
 	structure(object, class=c("summary.spautolm", class(object)))
 }
+#}
 
 print.summary.spautolm <- function(x, digits = max(5, .Options$digits - 3),
 	signif.stars = FALSE, ...)
 {
+    .Deprecated("spatialreg::print.summary.spautolm", msg="Method print.summary.spautolm moved to the spatialreg package")
+#    if (!requireNamespace("spatialreg", quietly=TRUE))
+#      stop("install the spatialreg package")
+    if (requireNamespace("spatialreg", quietly=TRUE)) {
+      return(spatialreg::print.summary.spautolm(x=x, digits = digits,
+	signif.stars = signif.stars, ...))
+    }
+    warning("install the spatialreg package")
+#  if (FALSE) {
 	cat("\nCall: ", deparse(x$call),	sep = "", fill=TRUE)
         if (isTRUE(all.equal(x$lambda, x$interval[1])) ||
             isTRUE(all.equal(x$lambda, x$interval[2]))) 
@@ -406,7 +498,9 @@ print.summary.spautolm <- function(x, digits = max(5, .Options$digits - 3),
     	cat("\n")
         invisible(x)
 }
+#}
 
+#if (FALSE) {
 getVcovmat <- function(coefs, env, tol.solve=.Machine$double.eps, optim=FALSE,
     optimM="optimHess") {
     if (optim) {
@@ -467,7 +561,7 @@ f_spautolm_hess <- function(coefs, env) {
     ret
 }
 
-
+#}
 
 
 
